@@ -63,6 +63,7 @@ our %KnownCommands = (
 	createMeeting => 'c',
 	createPreload => 'c',
 	createRecording => 'c',
+	createSession => 'c',
 	createUser => 'c',
 
 	deleteGroup => 'd',
@@ -117,6 +118,7 @@ our %KnownCommands = (
 	updateRecording => 'u',
 	updateReport => 'u',
 	updateServerParameters => 'u',
+	updateSession => 'u',
 	updateUser => 'u',
 
 	);
