@@ -3,7 +3,7 @@ use warnings; use strict;
 
 use Mouse;
 
-extends 'Elive::Entity';
+extends 'Elive::DAO::Singleton','Elive::Entity';
 
 use Scalar::Util;
 
@@ -43,22 +43,4 @@ has 'iNetAddress' => (is => 'rw', isa => 'Ref');
 
 =cut
 
-=head2 list
-
-    my ($server) = Elive::Entity::ServerDetails->list();
-
-Return the server details. Note that thiere is a single record. You should
-always expect to retrieve one record from each connection.
-
-=cut
-
-sub list {
-    my ($class, %opt) = @_;
-
-    die "filter not applicable to class $class"
-	if ($opt{filter});
-
-    return $class->_fetch({}, %opt);
-}
-
 1;
