@@ -13,7 +13,7 @@ use Elive::Entity::MeetingParameters;
 use Elive::Entity::ServerParameters;
 use Elive::Entity::ParticipantList;
 use Elive::Entity::Participants;
-use Elive::Array;
+use Elive::DAO::Array;
 
 =head1 NAME
 
@@ -35,10 +35,12 @@ __PACKAGE__->_alias(meetingId => 'id');
 __PACKAGE__->_alias(sessionId => 'id');
 
 __PACKAGE__->params(
+
     preloadIds => 'Elive::Entity::Preloads',
-    invitedParticipantsList => 'Elive::Array',
-    invitedModerators => 'Elive::Array',
-    invitedGuests => 'Elive::Array',
+
+    invitedParticipantsList => 'Elive::DAO::Array',
+    invitedModerators => 'Elive::DAO::Array',
+    invitedGuests => 'Elive::DAO::Array',
 
     timeZone                     => 'Str',
     until                        => 'HiResDate',
@@ -54,6 +56,7 @@ __PACKAGE__->params(
     thursdaySessionIndicator  => 'Bool',
     fridaySessionIndicator    => 'Bool',
     saturdaySessionIndicator  => 'Bool',
+
     );
 
 __PACKAGE__->mk_classdata(_delegates => {
@@ -268,7 +271,7 @@ sub _freeze_participants {
     my ($guests, $moderators, $others) = $participants->tidied();
 
     #
-    # Note: invited guest list is ';' seperated. Others are ',' separated.
+    # Note: invited guest list is ';' separated. Others are ',' separated.
     #
 
     $data->{invitedGuests} = join(';', @$guests);
@@ -400,8 +403,8 @@ sub update {
 
     if (@$changed || keys %update_data) {
 	#
-	# Early ELM 3.x has a habit of wiping defaults we're better off to
-	# rewrite the whole record
+	# Early ELM 3.x has a habit of wiping defaults. We're better off
+	# to rewrite the whole record
 	#
 	my @all_props =  map {$_->properties} values %{$self->_delegates};
 		       
@@ -599,7 +602,7 @@ to resolve login names and group names:
     my $tut_group = Elive::Entity::Group->list(filter => "groupName = 'Perl Tutorial Group 1'");
 
     my @participants = (-moderators => [$alice, $bob],
-                        -others => [@$tut_group],
+                        -others => $tut_group,
                        );
 
 Then, you just need to pass the list in when you create or update the session:
@@ -643,8 +646,8 @@ example, to print the list of participants for a session:
     my $participants = $session->participants;
 
     foreach my $participant (@$participants) {
+
 	my $type = $participant->type;
-	my $str;
 
 	if (! $type)  {
 	    my $user = $participant->user;
@@ -674,10 +677,11 @@ example, to print the list of participants for a session:
 		if $loginName;
 	}
 	else {
-	    die "unknown participant type $type"; # elm 4.x? ;-)
+	    die "unknown participant type: $type"; # elm 4.x? ;-)
 	}
 
-        print " [moderator]" if $participant->is_moderator;
+        print " [moderator]"
+            if $participant->is_moderator;
 
         print "\n";
     }
@@ -694,11 +698,11 @@ There are three types of preloads:
 
 =over 4
 
-=item (1) C<whiteboard>: file extension C<*.wbd>
+=item * C<whiteboard>: file extension C<*.wbd>, C<*.wbp>
 
-=item (2) C<plan> (Elluminate Plan!): file extensions: C<*.elp>,  C<*.elpx>
+=item * C<plan> (Elluminate Plan!): file extensions: C<*.elp>,  C<*.elpx>
 
-=item (3) C<media> (Multimedia): anything else
+=item * C<media> (Multimedia): anything else
 
 =back
 
@@ -1006,7 +1010,7 @@ L<Working with Participants>.
 
 =head2 password (Str)
 
-A password for the session (see L<Working with Participants>). 
+A password for the session.
 
 =head2 privateMeeting (Str)
 
